@@ -2,8 +2,6 @@
 """
 
 import os
-import xml.etree.ElementTree as ET
-from pdbeccdutils.helpers.drawing import svg_namespace
 
 
 def test__img_crated(library, tmpdir):
@@ -13,9 +11,6 @@ def test__img_crated(library, tmpdir):
 
     assert os.path.isfile(file_path)
 
-    xml = ET.parse(file_path)
-    assert len(xml.findall("svg:rect", svg_namespace)) > 100
-
 
 def test_img_png_created(library, tmpdir):
     file_path = str(tmpdir.join("library.png"))
